@@ -1,14 +1,14 @@
 <?php
 $CONFIG = array (
-  'passwordsalt' => 'cMbaJifjDD7/E/Pnab956uVttIQg7R',
-  'secret' => '+l35hYdIFlz8oV6ZS9ws/vOO1Zu8Iv+TnL+hSX5lpxeXGM/V',
+  'passwordsalt' => '2OMTFYv86AaGuES/RQfFEW0voZqacr',
+  'secret' => 'ENdYBknYh8qJMXDXrJJ+8T8hI02YM+C9apCbNN3onkDYmFkG',
   'trusted_domains' => 
   array (
     0 => 'localhost',
   ),
   'datadirectory' => '/var/www/nextcloud-data',
   'dbtype' => 'mysql',
-  'version' => '25.0.1.1',
+  'version' => '26.0.0.11',
   'overwrite.cli.url' => 'http://localhost',
   'dbname' => 'nextcloud',
   'dbhost' => 'localhost',
@@ -16,9 +16,9 @@ $CONFIG = array (
   'dbtableprefix' => 'oc_',
   'mysql.utf8mb4' => true,
   'dbuser' => 'nextcloud',
-  'dbpassword' => '198365d7c021bd9867618921ca056911',
+  'dbpassword' => '5b506783216a09366aafcbc1e070350d',
   'installed' => true,
-  'instanceid' => 'ocn1lrxc5y6e',
+  'instanceid' => 'ocm6idu29tg8',
   'memcache.local' => '\OC\Memcache\Redis',
   'redis' => array(
       'host' => '/var/run/redis/redis.sock',
